EquivocationProof

Struct EquivocationProof 

pub struct EquivocationProof<Header, Id> {
    pub offender: Id,
    pub slot: Slot,
    pub first_header: Header,
    pub second_header: Header,
}
Represents an equivocation proof. An equivocation happens when a validator produces more than one block on the same slot. The proof of equivocation are the given distinct headers that were signed by the validator and which include the slot number.

Fields

offender: Id

Returns the authority id of the equivocator.

slot: Slot

The slot at which the equivocation happened.

first_header: Header

The first header involved in the equivocation.

second_header: Header

The second header involved in the equivocation.