pub struct EquivocationProof<Header, Id> {
pub offender: Id,
pub slot: Slot,
pub first_header: Header,
pub second_header: Header,
}Expand description
Represents an equivocation proof. An equivocation happens when a validator produces more than one block on the same slot. The proof of equivocation are the given distinct headers that were signed by the validator and which include the slot number.
Fields
offender: IdReturns the authority id of the equivocator.
slot: SlotThe slot at which the equivocation happened.
first_header: HeaderThe first header involved in the equivocation.
second_header: HeaderThe second header involved in the equivocation.